@@ -6,7 +6,8 @@ test_that("/drugs/risk-factors", {
   r <- httr::RETRY("GET", glue::glue("{url}/drugs/risk-factors"),
     query = list(
       trait = trait
-    )
+    ),
+    config = httr::add_headers(.headers = c("client-type" = "R", "ci" = "true"))
   )
   expect_equal(httr::status_code(r), 200)
   expect_true(length(httr::content(r)) > 0)
