@@ -8,7 +8,8 @@ test_that("/literature/gwas", {
     query = list(
       trait = trait,
       semmed_predicate = semmed_predicate
-    )
+    ),
+    config = httr::add_headers(.headers = c("client-type" = "R", "ci" = "true"))
   )
   expect_equal(httr::status_code(r), 200)
   expect_true(length(httr::content(r)) > 0)
